aboutsummaryrefslogtreecommitdiffstats
path: root/whisper/whisper.go
diff options
context:
space:
mode:
Diffstat (limited to 'whisper/whisper.go')
-rw-r--r--whisper/whisper.go16
1 files changed, 11 insertions, 5 deletions
diff --git a/whisper/whisper.go b/whisper/whisper.go
index a341f23e4..7201062b8 100644
--- a/whisper/whisper.go
+++ b/whisper/whisper.go
@@ -98,9 +98,9 @@ func New() *Whisper {
return whisper
}
-// Protocol returns the whisper sub-protocol handler for this particular client.
-func (self *Whisper) Protocol() p2p.Protocol {
- return self.protocol
+// Protocols returns the whisper sub-protocols ran by this particular client.
+func (self *Whisper) Protocols() []p2p.Protocol {
+ return []p2p.Protocol{self.protocol}
}
// Version returns the whisper sub-protocols version number.
@@ -156,14 +156,20 @@ func (self *Whisper) Send(envelope *Envelope) error {
return self.add(envelope)
}
-func (self *Whisper) Start() {
+// Start implements node.Service, starting the background data propagation thread
+// of the Whisper protocol.
+func (self *Whisper) Start(*p2p.Server) error {
glog.V(logger.Info).Infoln("Whisper started")
go self.update()
+ return nil
}
-func (self *Whisper) Stop() {
+// Stop implements node.Service, stopping the background data propagation thread
+// of the Whisper protocol.
+func (self *Whisper) Stop() error {
close(self.quit)
glog.V(logger.Info).Infoln("Whisper stopped")
+ return nil
}
// Messages retrieves all the currently pooled messages matching a filter id.